aboutsummaryrefslogtreecommitdiffstats
path: root/Software/Visual_Studio/PPC/Tango.PPC.Common/Web/PPCWebClientBase.cs
diff options
context:
space:
mode:
authorRoy Ben-Shabat <Roy@Twine-s.com>2019-02-25 11:26:06 +0200
committerRoy Ben-Shabat <Roy@Twine-s.com>2019-02-25 11:26:06 +0200
commite068fa9d45e3ad6da977a08d722453756c38eee7 (patch)
tree775f8e4313105536dbaab1adf325c9655a0de750 /Software/Visual_Studio/PPC/Tango.PPC.Common/Web/PPCWebClientBase.cs
parentcc7cafd24fdb59afc78d198062c469344177f553 (diff)
downloadTango-e068fa9d45e3ad6da977a08d722453756c38eee7.tar.gz
Tango-e068fa9d45e3ad6da977a08d722453756c38eee7.zip
Updated PMR.
Diffstat (limited to 'Software/Visual_Studio/PPC/Tango.PPC.Common/Web/PPCWebClientBase.cs')
-rw-r--r--Software/Visual_Studio/PPC/Tango.PPC.Common/Web/PPCWebClientBase.cs12
1 files changed, 6 insertions, 6 deletions
diff --git a/Software/Visual_Studio/PPC/Tango.PPC.Common/Web/PPCWebClientBase.cs b/Software/Visual_Studio/PPC/Tango.PPC.Common/Web/PPCWebClientBase.cs
index 723e3ffc4..2df343241 100644
--- a/Software/Visual_Studio/PPC/Tango.PPC.Common/Web/PPCWebClientBase.cs
+++ b/Software/Visual_Studio/PPC/Tango.PPC.Common/Web/PPCWebClientBase.cs
@@ -59,12 +59,12 @@ namespace Tango.PPC.Common.Web
}
/// <summary>
/// Executes the CheckForUpdate action and returns Tango.PPC.Common.Web.CheckForUpdateResponse.
/// </summary>
/// <returns></returns>
- public Task<Tango.PPC.Common.Web.CheckForUpdateResponse> CheckForUpdate(Tango.PPC.Common.Web.CheckForUpdateRequest request)
+ public Task<Tango.PPC.Common.Web.CheckForUpdateResponse> CheckForUpdates(Tango.PPC.Common.Web.CheckForUpdateRequest request)
{
- return Post<Tango.PPC.Common.Web.CheckForUpdateRequest, Tango.PPC.Common.Web.CheckForUpdateResponse>("CheckForUpdate", request);
+ return Post<Tango.PPC.Common.Web.CheckForUpdateRequest, Tango.PPC.Common.Web.CheckForUpdateResponse>("CheckForUpdates", request);
}
/// <summary>
@@ -95,12 +95,12 @@ namespace Tango.PPC.Common.Web
}
/// <summary>
/// Executes the NotifyUploadCompleted action and returns Tango.PPC.Common.Web.UploadCompletedResponse.
/// </summary>
/// <returns></returns>
- public Task<Tango.PPC.Common.Web.UploadCompletedResponse> NotifyUploadCompleted(Tango.PPC.Common.Web.UploadCompletedRequest request)
+ public Task<Tango.PPC.Common.Web.UploadCompletedResponse> NotifyVersionUploadCompleted(Tango.PPC.Common.Web.UploadCompletedRequest request)
{
- return Post<Tango.PPC.Common.Web.UploadCompletedRequest, Tango.PPC.Common.Web.UploadCompletedResponse>("NotifyUploadCompleted", request);
+ return Post<Tango.PPC.Common.Web.UploadCompletedRequest, Tango.PPC.Common.Web.UploadCompletedResponse>("NotifyVersionUploadCompleted", request);
}
/// <summary>
@@ -59,12 +59,12 @@ namespace Tango.PPC.Common.Web
}
/// <summary>
- /// Executes the CheckForUpdate action and returns Tango.PPC.Common.Web.CheckForUpdateResponse.
+ /// Executes the CheckForUpdates action and returns Tango.PPC.Common.Web.CheckForUpdateResponse.
/// </summary>
/// <returns></returns>
@@ -95,12 +95,12 @@ namespace Tango.PPC.Common.Web
}
/// <summary>
- /// Executes the NotifyUploadCompleted action and returns Tango.PPC.Common.Web.UploadCompletedResponse.
+ /// Executes the NotifyVersionUploadCompleted action and returns Tango.PPC.Common.Web.UploadCompletedResponse.
/// </summary>
/// <returns></returns>